Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(765)

Unified Diff: chrome/browser/chromeos/gdata/gdata_file_system.h

Issue 10873005: Rename GDataDirectoryService to DriveResourceMetadata (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/gdata/gdata_file_system.h
diff --git a/chrome/browser/chromeos/gdata/gdata_file_system.h b/chrome/browser/chromeos/gdata/gdata_file_system.h
index 16786bcad0e07b3cdce9ce8881969f005d3f8abd..eb7df62c0e4c7a607b2971e6e870667cd5101240 100644
--- a/chrome/browser/chromeos/gdata/gdata_file_system.h
+++ b/chrome/browser/chromeos/gdata/gdata_file_system.h
@@ -16,8 +16,8 @@
#include "base/platform_file.h"
#include "base/timer.h"
#include "chrome/browser/api/prefs/pref_change_registrar.h"
+#include "chrome/browser/chromeos/gdata/drive_resource_metadata.h"
#include "chrome/browser/chromeos/gdata/gdata_cache.h"
-#include "chrome/browser/chromeos/gdata/gdata_directory_service.h"
#include "chrome/browser/chromeos/gdata/gdata_errorcode.h"
#include "chrome/browser/chromeos/gdata/gdata_file_system_interface.h"
#include "chrome/browser/chromeos/gdata/gdata_wapi_feed_loader.h"
@@ -424,7 +424,7 @@ class GDataFileSystem : public GDataFileSystemInterface,
// Callback for handling an attempt to move a file or directory from the
// root directory to another directory on the server side. This function
// moves |entry| to the root directory on the client side with
- // GDataDirectoryService::MoveEntryToDirectory().
+ // DriveResourceMetadata::MoveEntryToDirectory().
//
// |callback| must not be null.
void OnMoveEntryFromRootDirectoryCompleted(
@@ -667,7 +667,7 @@ class GDataFileSystem : public GDataFileSystemInterface,
const DriveEntryProto* entry_proto);
// Part of UpdateFileByResourceId(). Called when
// GDataDirectory::GetEntryInfoByResourceId() is complete.
// |callback| must not be null.
void UpdateFileByEntryInfo(
const FileOperationCallback& callback,
@@ -836,7 +836,7 @@ class GDataFileSystem : public GDataFileSystemInterface,
// All members should be accessed only on UI thread. Do not post tasks to
// other threads with base::Unretained(this).
- scoped_ptr<GDataDirectoryService> directory_service_;
+ scoped_ptr<DriveResourceMetadata> resource_metadata_;
// The profile hosts the GDataFileSystem via GDataSystemService.
Profile* profile_;
« no previous file with comments | « chrome/browser/chromeos/gdata/gdata_download_observer.cc ('k') | chrome/browser/chromeos/gdata/gdata_file_system.cc » ('j') | no next file with comments »
@@ -667,7 +667,7 @@ class GDataFileSystem : public GDataFileSystemInterface,
const DriveEntryProto* entry_proto);
// Part of UpdateFileByResourceId(). Called when
- // GDataDirectory::GetEntryInfoByResourceId() is complete.
+ // DriveDirectory::GetEntryInfoByResourceId() is complete.
// |callback| must not be null.
void UpdateFileByEntryInfo(

Powered by Google App Engine
This is Rietveld 408576698